#
# spec file for package python-python-editor
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-editor
Version:        1.0.4
Release:        3.1
Summary:        Python library to programmatically open an editor and capture the result
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/fmoo/python-editor
Source:         https://files.pythonhosted.org/packages/source/p/python-editor/python-editor-%{version}.tar.gz
# PATCH-FIX-UPSTREAM support-python312.patch https://github.com/fmoo/python-editor/commit/5023fafd265add111b29baca59b07f140daf75b7
Patch0:         support-python312.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if 0%{?is_opensuse}
BuildRequires:  nano
%endif
%python_subpackages

%description
python-editor is a library that provides the editor module for
programmatically interfacing with the editor defined in the EDITOR
environment variable.

%prep
%autosetup -p1 -n python-editor-%{version}

%build
find -type f -exec chmod 644 {} +
%pyproject_wheel

%install
%pyproject_install
%python_expand sed -i -e '/^#!\/usr\/bin\/env/d' %{buildroot}%{$python_sitelib}/editor.py
%python_expand %fdupes %{buildroot}%{$python_sitelib}/

# the example does not look like an unit test
# %%check
# export EDITOR='nano'
# Xpython_exec test.py

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/editor.py
%{python_sitelib}/python[-_]editor-%{version}*-info
%pycache_only %{python_sitelib}/__pycache__/editor*

%changelog
* Fri Jun 20 2025 Nico Krapp <nico.krapp@suse.com>
- Add support-python312.patch to not depend on distutils (boo#1245108)
- clean up duplicate files
* Tue Jun 10 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Thu May  9 2019 pgajdos@suse.com
- version update to 1.0.4
  * no upstream changelog
* Tue Dec 18 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Clairfy what the
  "system's EDITOR" is.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Aug 22 2017 tbechtold@suse.com
- update to 1.0.3:
  * don't re-split arguments
  * Version bump (1.0.2)
  * Version bump to 1.0.3
  * remove un-needed function
  * update README
- convert to singlespec
* Fri Sep 16 2016 toddrme2178@gmail.com
- Fix Download URL
* Thu Sep 15 2016 toddrme2178@gmail.com
- Update to 1.0.1
  * Detect tty and add helper function
  * Default to not using tty
  * Use branch instead of ternary operator
  * Use /dev/tty by default
* Wed Jan 13 2016 toddrme2178@gmail.com
- Update to 0.5
  * Add "vim.basic" and "vim.tiny" to editors
  * Check editor from path (and traverse symlinks)
- Update to 0.4
  * Added MANIFEST file to include README.md and LICENSE file in
    pypi tarball
* Fri Aug 21 2015 tbechtold@suse.com
- Initial packaging (version 0.3)
